@@ -282,7 +282,9 @@ EOF
 	grep -q "/var/run/resolv.conf.usb0" /etc/dnsmasq.conf || echo "resolv-file=/var/run/resolv.conf.usb0" >> /etc/dnsmasq.conf
 
 	ifconfig usb0 $USB_IP up
+	ifconfig lo 127.0.0.1 up
 	route add default gw ${USB_IP%.*}.$((${USB_IP##*.}-1))
+	/usr/sbin/dnsmasq -i lo -a 127.0.0.1 -z
 
 	mount -t devpts devpts /dev/pts
 
@@ -361,11 +363,13 @@ EOF
 		killall dropbear
 		killall utelnetd
 		killall udhcpd
+		killall dnsmasq
 		kill `cat /var/run/udhcpd.pid`
 		rm -f /var/run/udhcpd.pid /var/run/udhcpd.conf
 		rm -f /var/run/resolv.conf.usb0
 		route del default
 		ifconfig usb0 down
+		ifconfig lo down
 		umount /dev/pts
 		if [ "$PRODUCT" = "RX-51" ]; then
 			rmmod g_nokia
